.. _core_toplevel:

SQLAlchemy Core
===============

The breadth of SQLAlchemy’s SQL rendering engine, DBAPI integration,
transaction integration, and schema description services are documented here.
In contrast to the ORM’s domain-centric mode of usage, the SQL Expression
Language provides a schema-centric usage paradigm.

.. toctree::
    :maxdepth: 2

    tutorial
    expression_api
    schema
    types
    engines_connections
    api_basics
